local addonName, addon = ...

-- Create local vars
local DB -- assigned during ADDON_LOADED
local Main = addon
local GUI = {}
local UIBuilder = addon.UIBuilder
-- local Options = _G.BoostWaitlistOptions or {}
-- local Main = _G.BoostWaitlistMain
-- local GUI = _G.BoostWaitlistGUI
-- local Options = _G.BoostWaitlistOptions
-- addon.BoostWaitlistGUI = GUI
addon.GUI = GUI



-- Init functions
function GUI:Init()
  DB = _G.BoostWaitlistDB
  GUI.created = false
  GUI:CreateMinimapIcon()
  GUI:UpdateBrokerTexture()
  GUI:ShowMinimapIcon()
  if (not DB.Main.everActive) then
    GUI:HideMinimapIcon()
  end
end

-- Local functions

-- Main GUI creation
function GUI:Create()
  if GUI.created then return end
  GUI.created = true

  -- Main Frame --------------------------
  local frameName = "BoostWaitlistGUI-Frame"
  local frame = CreateFrame("Frame", frameName, UIParent)
  frame:ClearAllPoints()
  frame:SetPoint(DB.GUI.points[1], DB.GUI.points[2], DB.GUI.points[3], DB.GUI.points[4], DB.GUI.points[5])
  frame:SetSize(465, 480)
  frame:SetMovable(true)
  frame:EnableMouse(true)
  frame:RegisterForDrag("LeftButton")
  frame:SetScript("OnMouseDown", frame.StartMoving)
  frame:SetScript("OnMouseUp", function(self)
    self:StopMovingOrSizing()
    local a,b,c,d,e = self:GetPoint()
    DB.GUI.points = {a, nil, c, d, e}
  end)
  frame:SetToplevel(true)
  frame:SetClampedToScreen(true)
  frame:SetBackdrop({ bgFile = "Interface/Tooltips/UI-Tooltip-Background" })
  frame:SetBackdropColor(0.2, 0.2, 0.2, 0.8)
  tinsert(UISpecialFrames, frameName) -- allow Escape button to close the frame
  frame:Hide()
  GUI.mainFrame = frame

  -- Close Button ---------------------------
  frame.closeButton = CreateFrame("Button", frameName.."-CloseButton", frame, "UIPanelCloseButton")
  frame.closeButton:SetPoint("TOPRIGHT", frame, "TOPRIGHT", 0, 0)

  -- Title Frame ----------------------------
  frame.titleFrame = CreateFrame("Frame", frameName.."-TitleFrame", frame)
  frame.titleFrame:SetSize(10, 10)
  frame.titleFrame:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background"})
  frame.titleFrame:SetBackdropColor(0, 0, 0, 1)
  frame.titleFrame.text = frame.titleFrame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  frame.titleFrame.text:SetAllPoints(frame.titleFrame)
  frame.titleFrame.text:SetJustifyH("CENTER")
  frame.titleFrame.text:SetText(DB.Main.name.."'s Boosting")
  frame.titleFrame:ClearAllPoints()
  frame.titleFrame:SetPoint("TOPLEFT", frame, 10, -7)
  frame.titleFrame:SetPoint("BOTTOMRIGHT", frame, "TOPRIGHT", -30, -25)

  -- Party Section ------------------------------------------------------

  local vOffsetPer = 20

  -- Party Header Text -------------------
  frame.partyHeaderText = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  frame.partyHeaderText:SetPoint("LEFT", frame, "TOPLEFT", 20, vOffsetPer*-2)
  frame.partyHeaderText:SetJustifyH("LEFT")
  frame.partyHeaderText:SetText("Members")

  -- Balance Header Text -------------------
  frame.balanceHeaderText = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  frame.balanceHeaderText:SetPoint("LEFT", frame, "TOPLEFT", 120, vOffsetPer*-2)
  frame.balanceHeaderText:SetJustifyH("LEFT")
  frame.balanceHeaderText:SetText("Bal")

    -- Cost Header Text -------------------
    frame.balanceHeaderText = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
    frame.balanceHeaderText:SetPoint("LEFT", frame, "TOPLEFT", 180, vOffsetPer*-2)
    frame.balanceHeaderText:SetJustifyH("LEFT")
    frame.balanceHeaderText:SetText("Cost")

  -- Charge All Button ----------------
  frame.chargeAllButton = GUI:CreateButton(frameName.."-ChargeAllButton", frame, "TOPLEFT", 285, vOffsetPer*-2)
  GUI:ConfigureButton(frame.chargeAllButton, 80, vOffsetPer, "Charge All")
  frame.chargeAllButton:RegisterForClicks("LeftButtonUp")
  frame.chargeAllButton:SetScript("OnClick", function(self, button, down)
    Main:ChargeAll()
  end)

  -- Charge Amount EditBox ------------
  frame.chargeAmountBox = CreateFrame("EditBox", frameName.."-ChargeAmountBox", frame, "InputBoxTemplate")
  frame.chargeAmountBox:SetSize(25, vOffsetPer)
  frame.chargeAmountBox:SetPoint("CENTER", frame, "TOPLEFT", 345, vOffsetPer*-2)
  frame.chargeAmountBox:SetText(DB.Main.cost)
  frame.chargeAmountBox:SetAutoFocus(false)
  frame.chargeAmountBox:SetScript("OnEnterPressed", function(self)
    local cost = tonumber(self:GetText())
    if ((cost ~= nil) and (cost < 100)) then
      if (cost ~= DB.Main.cost) then
        DB.Main.cost = cost
        print("BoostWaitlist - Setting cost to "..cost.."g")
      end
    else
      print("Invalid cost input: "..self:GetText())
      self:SetText(DB.Main.cost)
    end
    self:HighlightText(0,0)
    self:ClearFocus()
    GUI:Update()
  end)
  frame.chargeAmountBox:SetScript("OnEscapePressed", function(self)
    self:HighlightText(0,0)
    self:ClearFocus()
  end)
  frame.chargeAmountBox:SetScript("OnEditFocusLost", function(self)
    self:SetText(DB.Main.cost)
  end)

  -- Charge Amount Text ---------------
  frame.chargeAmountText = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  frame.chargeAmountText:SetPoint("LEFT", frame, "TOPLEFT", 360, vOffsetPer*-2)
  frame.chargeAmountText:SetJustifyH("LEFT")
  frame.chargeAmountText:SetText("g")

  -- Party State Frames ----------------
  frame.partyNameText = {}
  frame.partyButtonWrapper = {}
  for i=1,4 do
    local vOffset = vOffsetPer*(i+2)*-1

    frame.partyNameText[i] = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
    frame.partyNameText[i]:SetPoint("LEFT", frame, "TOPLEFT", 20, vOffset)
    frame.partyNameText[i]:SetJustifyH("LEFT")
    frame.partyNameText[i]:SetText(Main:GetPartyNames()[i])

    local wrapper = CreateFrame("Frame", frameName.."-PartyButtonWrapper"..i, frame)
    frame.partyButtonWrapper[i] = wrapper
    wrapper:SetSize(375, vOffsetPer)
    wrapper:SetPoint("LEFT", frame, "TOPLEFT", 120, vOffset)  -- 120 was 150

    wrapper.balanceText = wrapper:CreateFontString(nil, "ARTWORK", "GameFontNormal")
    wrapper.balanceText:SetPoint("LEFT", wrapper, "LEFT", 0, 0)
    wrapper.balanceText:SetJustifyH("LEFT")
    wrapper.balanceText:SetText("100g")

    wrapper.actionButton = GUI:CreateButton(frameName.."-PartyActionButton"..i, wrapper, "LEFT", 155, 0)
    GUI:ConfigureButton(wrapper.actionButton, 60, vOffsetPer, "Charge")
    wrapper.actionButton:RegisterForClicks("LeftButtonUp")
    wrapper.actionButton:SetScript("OnClick", function(self, button, down)
      Main:ChargeBalance(frame.partyNameText[i]:GetText())
    end)

    wrapper.actionButton2 = GUI:CreateButton(frameName.."-PartyActionButton2"..i, wrapper, "LEFT", 215, 0)
    GUI:ConfigureButton(wrapper.actionButton2, 60, vOffsetPer, "Add")
    wrapper.actionButton2:RegisterForClicks("LeftButtonUp")
    wrapper.actionButton2:SetScript("OnClick", function(self, button, down)
      wrapper.actionButton2:Hide()
      wrapper.depositAmountBox:SetText(DB.Main.cost*3)
      wrapper.depositAmountBox:HighlightText()
      wrapper.depositAmountBox:Show()
      wrapper.depositAmountBox:SetFocus(true)
    end)

    wrapper.tradeButton = GUI:CreateButton(frameName.."-PartyTradeButton"..i, wrapper, "LEFT", 275, 0)
    GUI:ConfigureButton(wrapper.tradeButton, 60, vOffsetPer, "Trade")
    wrapper.tradeButton:RegisterForClicks("LeftButtonUp")
    wrapper.tradeButton:SetScript("OnClick", function(self, button, down)
      InitiateTrade(frame.partyNameText[i]:GetText())
    end)


    wrapper.chargeAmountOverrideBox = CreateFrame("EditBox", frameName.."-ChargeAmountOverrideBox"..i, wrapper, "InputBoxTemplate")
    wrapper.chargeAmountOverrideBox:SetSize(25, vOffsetPer)
    wrapper.chargeAmountOverrideBox:SetPoint("CENTER", wrapper, "LEFT", 77, 0)
    wrapper.chargeAmountOverrideBox:SetText(Main:GetOverrideDefaultCharge(frame.partyNameText[i]:GetText()) or DB.Main.cost)
    wrapper.chargeAmountOverrideBox:SetAutoFocus(false)
    wrapper.chargeAmountOverrideBox:SetScript("OnEnterPressed", function(self)
      self:ClearFocus()
      self:HighlightText(0,0)
      local cost = tonumber(self:GetText())
      if (cost ~= nil) then
        Main:SetOverrideDefaultCharge(frame.partyNameText[i]:GetText(), cost)
      else
        self:SetText(DB.Main.cost)
      end
    end)
    wrapper.chargeAmountOverrideBox:SetScript("OnEditFocusLost", function(self)
      -- self:Hide()
      -- wrapper.actionButton2:Show()
    end)

    wrapper.depositAmountBox = CreateFrame("EditBox", frameName.."-DepositAmountBox", wrapper, "InputBoxTemplate")
    wrapper.depositAmountBox:SetSize(40, vOffsetPer)
    wrapper.depositAmountBox:SetPoint("CENTER", wrapper, "LEFT", 215, 0)
    wrapper.depositAmountBox:SetText("")
    wrapper.depositAmountBox:SetAutoFocus(false)
    wrapper.depositAmountBox:Hide()
    wrapper.depositAmountBox:SetScript("OnEnterPressed", function(self)
      self:ClearFocus()
      self:HighlightText(0,0)
      local cost = tonumber(self:GetText())
      if (cost ~= nil) then
        Main:AddBalance(frame.partyNameText[i]:GetText(), cost)
	      self:Hide()
        wrapper.actionButton2:Show()
      else
        print("Invalid balance input: "..self:GetText())
        self:SetText("")
      end
    end)
    wrapper.depositAmountBox:SetScript("OnEditFocusLost", function(self)
      self:Hide()
      wrapper.actionButton2:Show()
    end)
  end

  -- Waitlist Section ---------------------------------------------------

  -- Request Header Text -----------------
  frame.waitlistHeaderText = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  frame.waitlistHeaderText:SetPoint("LEFT", frame, "TOPLEFT", 20, vOffsetPer*-10)
  frame.waitlistHeaderText:SetJustifyH("LEFT")
  frame.waitlistHeaderText:SetText("Waitlist")

  frame.waitlistAltHeaderText = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  frame.waitlistAltHeaderText:SetPoint("LEFT", frame, "TOPLEFT", 150, vOffsetPer*-10)
  frame.waitlistAltHeaderText:SetJustifyH("LEFT")
  frame.waitlistAltHeaderText:SetText("Waiting On")

  -- Update Button -----------------------
  frame.updateButton = GUI:CreateButton(frameName.."-UpdateButton", frame, "TOPLEFT", 285, vOffsetPer*-10)
  GUI:ConfigureButton(frame.updateButton, 60, vOffsetPer, "Update")
  frame.updateButton:RegisterForClicks("LeftButtonUp")
  frame.updateButton:SetScript("OnClick", function(self, button, down)
    GUI:Update()
  end)

  -- Forming Text -------------------------
  frame.formingText = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  frame.formingText:SetPoint("CENTER", frame, "TOPLEFT", 350, vOffsetPer*-10)
  frame.formingText:SetJustifyH("CENTER")
  frame.formingText:SetText(DB.Main.forming and "Forming" or "Full")

  -- Forming Button -----------------------
  frame.formingButton = GUI:CreateButton(frameName.."-FormingButton", frame, "TOPLEFT", 415, vOffsetPer*-10)
  GUI:ConfigureButton(frame.formingButton, 60, vOffsetPer, "Toggle")
  frame.formingButton:RegisterForClicks("LeftButtonUp")
  frame.formingButton:SetScript("OnClick", function(self, button, down)
    DB.Main.forming = (DB.Main.forming == false)
    frame.formingText:SetText(DB.Main.forming and "Forming" or "Full")
  end)

  -- Request State Frames ----------------
  frame.waitlistNameText = {}
  frame.waitlistButtonWrapper = {}
  for i=1,13 do
    local vOffset = vOffsetPer*(i+10)*-1

    frame.waitlistNameText[i] = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
    frame.waitlistNameText[i]:SetPoint("LEFT", frame, "TOPLEFT", 20, vOffset)
    frame.waitlistNameText[i]:SetJustifyH("LEFT")
    frame.waitlistNameText[i]:SetText("Player"..i)

    local wrapper = CreateFrame("Frame", frameName.."-WaitlistButtonWrapper"..i, frame)
    frame.waitlistButtonWrapper[i] = wrapper
    wrapper:SetSize(375, vOffsetPer)
    wrapper:SetPoint("LEFT", frame, "TOPLEFT", 150, vOffset)

    wrapper.altNameText = wrapper:CreateFontString(nil, "ARTWORK", "GameFontNormal")
    wrapper.altNameText:SetPoint("LEFT", wrapper, "LEFT", 0, 0)
    wrapper.altNameText:SetJustifyH("LEFT")
    wrapper.altNameText:SetText("Player"..i)

    wrapper.actionButton = GUI:CreateButton(frameName.."-WaitlistActionButton"..i, wrapper, "LEFT", 135, 0)
    GUI:ConfigureButton(wrapper.actionButton, 60, vOffsetPer, "Action")
    wrapper.actionButton:RegisterForClicks("LeftButtonUp")
    wrapper.actionButton:SetScript("OnClick", function(self, button, down)
      Main:HandleActionButtonPress(frame.waitlistNameText[i]:GetText(), wrapper.actionButton:GetText())
    end)

    wrapper.actionButton2 = GUI:CreateButton(frameName.."-WaitlistActionButton2"..i, wrapper, "LEFT", 200, 0)
    GUI:ConfigureButton(wrapper.actionButton2, 60, vOffsetPer, "Action")
    wrapper.actionButton2:RegisterForClicks("LeftButtonUp")
    wrapper.actionButton2:SetScript("OnClick", function(self, button, down)
      Main:HandleActionButtonPress(frame.waitlistNameText[i]:GetText(), wrapper.actionButton2:GetText())
    end)

    wrapper.removeButton = GUI:CreateButton(frameName.."-WaitlistRemoveButton"..i, wrapper, "LEFT", 265, 0)
    GUI:ConfigureButton(wrapper.removeButton, 60, vOffsetPer, "Remove")
    wrapper.removeButton:RegisterForClicks("LeftButtonUp")
    wrapper.removeButton:SetScript("OnClick", function(self, button, down)
      Main:HandleRemoveButtonPress(frame.waitlistNameText[i]:GetText())
    end)
  end
end

function GUI:CreatePopupFrame()
  -- Popup Frame --------------------------
  local frameName = "HPCustomerGUI-PopupFrame"
  local popupFrame = CreateFrame("Frame", frameName, UIParent)
  popupFrame:ClearAllPoints()
  popupFrame:SetPoint("CENTER", 0, 0)
  popupFrame:SetSize(520, 110)
  popupFrame:SetMovable(true)
  popupFrame:EnableMouse(true)
  popupFrame:RegisterForDrag("LeftButton")
  popupFrame:SetScript("OnMouseDown", popupFrame.StartMoving)
  popupFrame:SetScript("OnMouseUp", popupFrame.StopMovingOrSizing)
  popupFrame:SetToplevel(true)
  popupFrame:SetClampedToScreen(true)
  popupFrame:SetBackdrop({ bgFile = "Interface/Tooltips/UI-Tooltip-Background" })
  popupFrame:SetBackdropColor(0, 0, 0, 1)
  popupFrame:Hide()
  GUI.popupFrame = popupFrame

  -- Popup Title Frame ----------------------------
  popupFrame.titleFrame = CreateFrame("Frame", frameName.."-TitleFrame", popupFrame)
  popupFrame.titleFrame:SetSize(10, 10)
  popupFrame.titleFrame:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background"})
  popupFrame.titleFrame:SetBackdropColor(0, 0, 0, 1)
  popupFrame.titleFrame.text = popupFrame.titleFrame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  popupFrame.titleFrame.text:SetAllPoints(popupFrame.titleFrame)
  popupFrame.titleFrame.text:SetJustifyH("CENTER")
  popupFrame.titleFrame.text:SetText(DB.Main.name.."'s Boosting")
  popupFrame.titleFrame:ClearAllPoints()
  popupFrame.titleFrame:SetPoint("TOPLEFT", popupFrame, 10, -7)
  popupFrame.titleFrame:SetPoint("BOTTOMRIGHT", popupFrame, "TOPRIGHT", -30, -25)

  -- Popup Frame Text ---------------------------
  popupFrame.text = popupFrame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
  popupFrame.text:SetPoint("CENTER", popupFrame, "CENTER", 0, 0) 
  popupFrame.text:SetJustifyH("CENTER")

  -- Popup Left Button -------------------
  popupFrame.leftButton = GUI:CreateButton(frameName.."-LeftButton", popupFrame, "CENTER", -70, -40)
  GUI:ConfigureButton(popupFrame.leftButton, 48, 20, "Confirm")
  popupFrame.leftButton:RegisterForClicks("LeftButtonUp")

  -- Popup Right Button -------------------
  popupFrame.rightButton = GUI:CreateButton(frameName.."-RightButton", popupFrame, "CENTER", 70, -40)
  GUI:ConfigureButton(popupFrame.rightButton, 48, 20, "Cancel")
  popupFrame.rightButton:RegisterForClicks("LeftButtonUp")
end

function GUI:UpdateBrokerTexture()
    local i = "Interface\\AddOns\\BoostWaitlist\\res\\ability_warrior_charge_grey"
    if (DB.Main.active) then
      i = "Interface\\Icons\\Ability_Warrior_Charge"
    end
    GUI.minimapLDB.icon = i
end

function GUI:CreateMinimapIcon()
  -- Minimap Button ------------------------
  GUI.minimapButton = LibStub("LibDBIcon-1.0")
  GUI.minimapLDB = LibStub("LibDataBroker-1.1"):NewDataObject("BoostWaitlist", {
    type = "launcher",
    text = "BoostWaitlist",
    icon = "Interface\\AddOns\\BoostWaitlist\\res\\ability_warrior_charge_grey",
    OnClick = 
      function(_, button) 
        if (button == "LeftButton") then
          GUI:ShowToggle()
        elseif (button == "RightButton") then
          if (IsShiftKeyDown()) then
            InterfaceOptionsFrame_OpenToCategory("BoostWaitlist");
          else
            if (DB.Main.active) then
              Main:HandleAddonOff()
            else
              Main:HandleAddonOn()
            end
          end
        end
      end,
    OnTooltipShow = function(tt)
      tt:AddLine("BoostWaitlist")
      tt:AddLine("Click to open/close the BoostWaitlist GUI")
      tt:AddLine("Right-click to activate BoostWaitlist")
      tt:AddLine("Shift Right-click to open config panel")
    end,
  })

  GUI.minimapButton:Register("BoostWaitlist", GUI.minimapLDB, DB.GUI.minimap)
end

-- Show / Hide functions
function GUI:Show()
  if (GUI.mainFrame ~= nil) then
    GUI:Update(true)
    GUI.mainFrame:Show()
  end
end

function GUI:ShowToggle()
  if (GUI.mainFrame ~= nil) then
    if (GUI.mainFrame:IsShown()) then
      GUI.mainFrame:Hide()
    else
      GUI:Show()
    end
  else
    GUI:Create()
    GUI:Show()
  end
end

function GUI:UpdateName(name)
  if (GUI.mainFrame ~= nil) then
    GUI.mainFrame.titleFrame.text:SetText(name.."'s Boosting")
  end
end

function GUI:Update(preShowCall)
  local frame = GUI.mainFrame
  if ((frame == nil) or (not preShowCall and not frame:IsShown())) then
    return
  else
    local partyNames = Main:GetPartyNames()
    local lineNum = 1
    for i=1,#partyNames do
      frame.partyNameText[i]:SetText(partyNames[i])
      frame.partyNameText[i]:Show()

      local wrapper = frame.partyButtonWrapper[i]
      if (Main:BalanceExists(partyNames[i])) then
        wrapper.balanceText:SetText(Main:GetBalance(partyNames[i]).."g")
      else
        wrapper.balanceText:SetText("None")
      end
      wrapper.chargeAmountOverrideBox:SetText(Main:GetOverrideDefaultCharge(frame.partyNameText[i]:GetText()) or DB.Main.cost)
      wrapper:Show()
      lineNum = lineNum + 1
      if (lineNum > 4) then break end
    end

    for i=lineNum,4 do
      frame.partyNameText[i]:Hide()
      frame.partyButtonWrapper[i]:Hide()
    end

    local waitlistInfo = Main:GetWaitlistInfo()
    lineNum = 1
    for i=1,#waitlistInfo.waitlist do
      local wlInfo = waitlistInfo.waitlist[i]
      frame.waitlistNameText[lineNum]:SetText(wlInfo.target)
      frame.waitlistNameText[lineNum]:Show()

      local wrapper = frame.waitlistButtonWrapper[lineNum]
      wrapper.altNameText:SetText(wlInfo.sender)
      wrapper.actionButton:SetText(Main:GetActionButtonText(wlInfo.target))
      wrapper.actionButton2:SetText(Main:GetActionButtonText2(wlInfo.target))
      wrapper:Show()
      lineNum = lineNum + 1
      if (lineNum > 13) then break end
    end

    for i=lineNum,13 do
      frame.waitlistNameText[i]:Hide()
      frame.waitlistButtonWrapper[i]:Hide()
    end
  end
end

function GUI:ShowPopupFrame(reason)
  if (GUI.popupFrame == nil) then
    GUI:CreatePopupFrame()
  end

  if (reason == "DONE_BOOSTING") then
    GUI.popupFrame.text:SetText("You turned BoostWaitlist off, but you still have players in the waitlist.|nDo you want to clear the waitlist and whisper those players that you're done?")
    GUI.popupFrame.leftButton:SetText("Yes")
    GUI.popupFrame.leftButton:SetScript("OnClick", function(self, button, down)
      Main:NotifyClearWaitlist()
      GUI.popupFrame:Hide()
    end)
    GUI.popupFrame.rightButton:SetText("No")
    GUI.popupFrame.rightButton:SetScript("OnClick", function(self, button, down)
      GUI.popupFrame:Hide()
    end)
    GUI.popupFrame:Show()
  end
end

function GUI:ShowMinimapIcon()
  DB.GUI.minimap.hide = false
  if (GUI.minimapButton ~= nil) then
    GUI.minimapButton:Show("BoostWaitlist")
  end
end

function GUI:HideMinimapIcon()
  DB.GUI.minimap.hide = true
  if (GUI.minimapButton ~= nil) then
    GUI.minimapButton:Hide("BoostWaitlist")
  end
end

-- Button functions
function GUI:CreateButton(name, parent, anchor, hpos, vpos)
  local button = CreateFrame("Button", name, parent)
  button:SetPoint("CENTER", parent, anchor, hpos, vpos)
  return button
end

function GUI:ConfigureButton(button, width, height, text)
  button:SetSize(width, height)
  button:SetText(text)
  button:SetNormalFontObject("GameFontNormal")

  local ntex = button:CreateTexture()
  ntex:SetTexture("Interface/Buttons/UI-Panel-Button-Up")
  ntex:SetTexCoord(0, 0.625, 0, 0.6875)
  ntex:SetAllPoints()	
  button:SetNormalTexture(ntex)
  
  local htex = button:CreateTexture()
  htex:SetTexture("Interface/Buttons/UI-Panel-Button-Highlight")
  htex:SetTexCoord(0, 0.625, 0, 0.6875)
  htex:SetAllPoints()
  button:SetHighlightTexture(htex)
  
  local ptex = button:CreateTexture()
  ptex:SetTexture("Interface/Buttons/UI-Panel-Button-Down")
  ptex:SetTexCoord(0, 0.625, 0, 0.6875)
  ptex:SetAllPoints()
  button:SetPushedTexture(ptex)
end

